CMIP6 source_id license details
Author: Paul J. Durack
Description: Controlled vocabulary for CMIP6
Keywords: HTML, CSS, JavaScript

# WCRP-CMIP CMIP6_CVs version: 6.2.60.0

#### Experiment IDs | Institution IDs | Source IDs | Source IDs (incl licenses) | Citations by (Source ID, Institution Id, Activity ID) | Citations by (Source ID, Institution Id, Activity ID, Experiment ID) |

source id | institution id | release year | cohort | label | label extended | license | exceptions contact | history | source specific info
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
source id | institution id | release year | cohort | label | label extended | license | exceptions contact | history | source specific info
4AOP-v1-5 | IPSL | 2019 | Published | 4AOP-v1-5 | Line-By-Line Radiative Transfer Model v1.5, Laboratoire Meteorologie Dynamique, GEISA spectroscopic database | CC BY 4.0 | @listes.ipsl.fr <- ipsl-cmip6 | 2020-06-11: initially published under CC BY-NC-SA 4.0; 2022-06-03: relaxed to CC BY 4.0 |
ACCESS-CM2 | CSIRO-ARCCSS | 2019 | Published | ACCESS-CM2 | Australian Community Climate and Earth System Simulator Climate Model Version 2 | CC BY 4.0 | @csiro.au <- access_csiro | 2019-11-08: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
ACCESS-ESM1-5 | CSIRO | 2019 | Published | ACCESS-ESM1.5 | Australian Community Climate and Earth System Simulator Earth System Model Version 1.5 | CC BY 4.0 | @csiro.au <- access_csiro | 2019-11-12: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
ACCESS-OM2 | CSIRO-COSIMA | 2020 | Published | ACCESS-OM2 | Australian Community Climate and Earth System Simulator Ocean Model Version 2 | CC BY 4.0 | @csiro.au <- access_csiro | 2021-06-16: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
ACCESS-OM2-025 | CSIRO-COSIMA | 2020 | Published | ACCESS-OM2-025 | Australian Community Climate and Earth System Simulator Ocean Model Version 2 quarter degree | CC BY 4.0 | @csiro.au <- access_csiro | 2021-06-17: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
ARTS-2-3 | UHH | 2015 | Published | ARTS 2.3 | ARTS 2.3 (Current development version of the Atmospheric Radiative Transfer Simulator) | CC BY 4.0 | @uni-hamburg.de <- oliver.lemke | 2019-06-20: initially published under CC BY-NC-SA 4.0; 2022-07-31: relaxed to CC BY 4.0 |
AWI-CM-1-1-HR | AWI | 2018 | Published | AWI-CM 1.1 HR | AWI-CM 1.1 HR | CC BY 4.0 | @awi.de <- mip-contact | 2017-08-25: initially published under CC BY-SA 4.0; 2022-06-22: relaxed to CC BY 4.0 |
AWI-CM-1-1-LR | AWI | 2018 | Published | AWI-CM 1.1 LR | AWI-CM 1.1 LR | CC BY 4.0 | @awi.de <- mip-contact | 2017-08-25: initially published under CC BY-SA 4.0; 2022-06-22: relaxed to CC BY 4.0 |
AWI-CM-1-1-MR | AWI | 2018 | Published | AWI-CM 1.1 MR | AWI-CM 1.1 MR | CC BY 4.0 | @awi.de <- mip-contact | 2018-12-18: initially published under CC BY-SA 4.0; 2022-06-22: relaxed to CC BY 4.0 |
AWI-ESM-1-1-LR | AWI | 2018 | Published | AWI-ESM 1.1 LR | AWI-ESM 1.1 LR | CC BY 4.0 | @awi.de <- mip-contact | 2020-02-12: initially published under CC BY-SA 4.0; 2022-06-22: relaxed to CC BY 4.0 |
AWI-ESM-1-REcoM | AWI | 2024 | Published | AWI-ESM 1 REcoM | AWI-ESM 1 REcoM | CC BY 4.0 | @awi.de <- mip-contact | 2024-07-04: initially published under CC BY 4.0 |
BCC-CSM2-HR | BCC | 2017 | Published | BCC-CSM 2 HR | BCC-CSM 2 HR | CC BY 4.0 | @cma.gov.cn <- twwu | 2020-07-21: initially published under CC BY-SA 4.0; 2022-09-28 relaxed to CC BY 4.0 |
BCC-CSM2-MR | BCC | 2017 | Published | BCC-CSM 2 MR | BCC-CSM 2 MR | CC BY 4.0 | @cma.gov.cn <- twwu | 2018-10-09: initially published under CC BY-SA 4.0; 2022-09-28 relaxed to CC BY 4.0 |
BCC-ESM1 | BCC | 2017 | Published | BCC-ESM 1 | BCC-ESM 1 | CC BY 4.0 | @cma.gov.cn <- twwu | 2018-11-14: initially published under CC BY-SA 4.0; 2022-09-28 relaxed to CC BY 4.0 |
CAM-MPAS-HR | PNNL-WACCEM | 2018 | Published | CAM-MPAS-HR | CAM MPAS (Community Atmosphere Model - Model for Prediction Across Scales) | CC BY 4.0 | @pnnl.gov <- bryce.harrop | 2025-03-25: initially published under CC BY 4.0 |
CAM-MPAS-LR | PNNL-WACCEM | 2018 | Published | CAM-MPAS-LR | CAM MPAS (Community Atmosphere Model - Model for Prediction Across Scales) | CC BY 4.0 | @pnnl.gov <- bryce.harrop | 2025-03-25: initially published under CC BY 4.0 |
CAMS-CSM1-0 | CAMS | 2016 | Published | CAMS-CSM 1.0 | CAMS-CSM 1.0 | CC BY 4.0 | @cma.gov.cn <- rongxy | 2019-07-08: initially published under CC BY-SA 4.0; 2022-09-29 relaxed to CC BY 4.0 |
CAS-ESM2-0 | CAS | 2019 | Published | CAS-ESM 2.0 | CAS-ESM 2.0 (Chinese Academy of Sciences Earth System Model version 2.0) | CC BY 4.0 | @mail.iap.ac.cn <- zhanghe | 2020-03-01: initially published under CC BY-SA 4.0; 2022-10-04: relaxed to CC BY 4.0 |
CESM1-1-CAM5-CMIP5 | NCAR | 2011 | Published | CESM1-1-CAM5-CMIP5 | CESM1-1-CAM5-CMIP5 | CC BY 4.0 | @ucar.edu <- cesm_cmip6 | 2019-10-07: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
CESM1-CAM5-SE-HR | NCAR | 2012 | Published | CESM1-CAM5-SE-HR | CESM 1.3 CAM5 spectral element configuration with CMIP5 forcings, hi res | CC BY 4.0 | @ucar.edu <- cesm_cmip6 | 2020-07-24: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
CESM1-CAM5-SE-LR | NCAR | 2012 | Published | CESM1-CAM5-SE-LR | CESM 1.3 CAM5 spectral element configuration with CMIP5 forcings, lo res | CC BY 4.0 | @ucar.edu <- cesm_cmip6 | 2020-07-08: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
CESM1-WACCM-SC | UCI NCAR | 2011 | Published | CESM1-WACCM-SC | Community Earth System Model 1, with the Whole Atmosphere Community Climate Model and Specified Chemistry | CC BY 4.0 | @ucar.edu <- cesm_cmip6 | 2020-10-12: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
CESM2 | NCAR | 2018 | Published | CESM2 | CESM2 | CC BY 4.0 | @ucar.edu <- cesm_cmip6 | 2019-02-18: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
CESM2-FV2 | NCAR | 2019 | Published | CESM2-FV2 | CESM2-FV2 | CC BY 4.0 | @ucar.edu <- cesm_cmip6 | 2019-11-20: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
CESM2-WACCM | NCAR | 2018 | Published | CESM2-WACCM | CESM2-WACCM | CC BY 4.0 | @ucar.edu <- cesm_cmip6 | 2019-02-20: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
CESM2-WACCM-FV2 | NCAR | 2019 | Published | CESM2-WACCM-FV2 | CESM2-WACCM-FV2 | CC BY 4.0 | @ucar.edu <- cesm_cmip6 | 2019-11-20: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
CIESM | THU | 2017 | Published | CIESM | Community Integrated Earth System Model | CC BY 4.0 | @tsinghua.edu.cn <- yanluan | 2019-12-02: initially published under CC BY-SA 4.0; 2022-07-27: relaxed to CC BY 4.0 |
CMCC-CM2-HR4 | CMCC | 2016 | Published | CMCC-CM2-HR4 | CMCC-CM2-HR4 | CC BY 4.0 | @cmcc.it <- silvio.gualdi | 2017-07-06: initially published under CC BY-SA 4.0; 2022-06-27: relaxed to CC BY 4.0 |
CMCC-CM2-SR5 | CMCC | 2016 | Published | CMCC-CM2-SR5 | CMCC-CM2-SR5 | CC BY 4.0 | @cmcc.it <- silvio.gualdi | 2020-02-26: initially published under CC BY-SA 4.0; 2022-06-27: relaxed to CC BY 4.0 |
CMCC-CM2-VHR4 | CMCC | 2017 | Published | CMCC-CM2-VHR4 | CMCC-CM2-VHR4 | CC BY 4.0 | @cmcc.it <- enrico.scoccimarro | 2017-09-27: initially published under CC BY-SA 4.0; 2022-06-27: relaxed to CC BY 4.0 |
CMCC-ESM2 | CMCC | 2017 | Published | CMCC-ESM2 | CMCC-ESM2 | CC BY 4.0 | @cmcc.it <- tomas.lovato | 2020-02-03: initially published under CC BY-SA 4.0; 2022-06-27: relaxed to CC BY 4.0 |
CNRM-CM6-1 | CNRM-CERFACS | 2017 | Published | CNRM-CM6-1 | CNRM-CM6-1 | CC BY 4.0 | @cerfacs.fr <- contact.cmip6 | 2018-06-26: initially published under CC BY-NC-SA 4.0; 2022-06-17: relaxed to CC BY 4.0 |
CNRM-CM6-1-HR | CNRM-CERFACS | 2017 | Published | CNRM-CM6-1-HR | CNRM-CM6-1-HR | CC BY 4.0 | @cerfacs.fr <- contact.cmip6 | 2019-02-21: initially published under CC BY-NC-SA 4.0; 2022-06-17: relaxed to CC BY 4.0 |
CNRM-ESM2-1 | CNRM-CERFACS | 2017 | Published | CNRM-ESM2-1 | CNRM-ESM2-1 | CC BY 4.0 | @meteo.fr <- contact.cmip | 2018-09-14: initially published under CC BY-NC-SA 4.0; 2022-06-17: relaxed to CC BY 4.0 |
CanESM5 | CCCma | 2019 | Published | CanESM5 | CanESM5 | CC BY 4.0 | @ec.gc.ca <- f.cccma.info-info.ccmac.f | 2019-03-06: initially published under CC BY-SA 4.0; 2022-09-27: relaxed to CC BY 4.0 |
CanESM5-1 | CCCma | 2022 | Published | CanESM5.1 | CanESM5.1 | CC BY 4.0 | @ec.gc.ca <- f.cccma.info-info.ccmac.f | 2022-12-02: initially published under CC BY 4.0 |
CanESM5-CanOE | CCCma | 2019 | Published | CanESM5-CanOE | CanESM5-CanOE | CC BY 4.0 | @ec.gc.ca <- f.cccma.info-info.ccmac.f | 2019-04-29: initially published under CC BY-SA 4.0; 2022-09-27: relaxed to CC BY 4.0 |
E3SM-1-0 | E3SM-Project LLNL UCI UCSB | 2018 | Published | E3SM 1.0 | E3SM 1.0 (Energy Exascale Earth System Model) | CC BY 4.0 | @llnl.gov <- e3sm-data-support | 2019-02-06: initially published under CC BY-SA 4.0; 2022-06-15: relaxed to CC BY 4.0 |
E3SM-1-1 | E3SM-Project RUBISCO | 2019 | Published | E3SM 1.1 | E3SM 1.1 (Energy Exascale Earth System Model) | CC BY 4.0 | @llnl.gov <- e3sm-data-support | 2019-10-29: initially published under CC BY-SA 4.0; 2022-06-15: relaxed to CC BY 4.0 |
E3SM-1-1-ECA | E3SM-Project | 2019 | Published | E3SM 1.1 ECA | E3SM 1.1 (Energy Exascale Earth System Model) with an experimental land BGC ECA configuration | CC BY 4.0 | @llnl.gov <- e3sm-data-support | 2019-12-16: initially published under CC BY-SA 4.0; 2022-06-15: relaxed to CC BY 4.0 |
E3SM-2-0 | E3SM-Project | 2022 | Published | E3SM 2.0 | E3SM 2.0 (Energy Exascale Earth System Model) | CC BY 4.0 | @llnl.gov <- e3sm-data-support | 2022-08-23: initially published under CC BY 4.0 |
E3SM-2-0-NARRM | E3SM-Project | 2022 | Published | E3SM 2.0 NARRM | E3SM 2.0 NARRM (Energy Exascale Earth System Model version 2.0 North American Regionally Refined Model) | CC BY 4.0 | @llnl.gov <- e3sm-data-support | 2023-04-26: initially published under CC BY 4.0 |
E3SM-2-1 | E3SM-Project | 2024 | Published | E3SM 2.1 | E3SM 2.1 (Energy Exascale Earth System Model) | CC BY 4.0 | @llnl.gov <- e3sm-data-support | 2024-02-05: initially published under CC BY 4.0 |
EC-Earth3 | EC-Earth-Consortium | 2019 | Published | EC-Earth3 | EC Earth 3.3 | CC BY 4.0 | @ec-earth.org <- cmip6-data | 2019-04-05: initially published under CC BY-SA 4.0; 2022-06-02: relaxed to CC BY 4.0 |
EC-Earth3-AerChem | EC-Earth-Consortium | 2019 | Published | EC-Earth3-AerChem | EC-Earth3-AerChem | CC BY 4.0 | @ec-earth.org <- cmip6-data | 2020-06-22: initially published under CC BY-SA 4.0; 2022-06-02: relaxed to CC BY 4.0 |
EC-Earth3-CC | EC-Earth-Consortium | 2019 | Published | EC-Earth3-CC | EC-Earth3-CC | CC BY 4.0 | @ec-earth.org <- cmip6-data | 2020-12-29: initially published under CC BY-SA 4.0; 2022-06-02: relaxed to CC BY 4.0 |
EC-Earth3-ESM-1 | EC-Earth-Consortium | 2024 | Published | EC-Earth3-ESM-1 | EC-Earth3-ESM-1 | CC BY 4.0 | @ec-earth.org <- cmip6-data | 2024-09-25: initially published under CC BY 4.0 |
EC-Earth3-HR | EC-Earth-Consortium | 2019 | Published | EC-Earth3-HR | EC-Earth3-HR | CC BY 4.0 | @ec-earth.org <- cmip6-data | 2022-06-27: initially published under CC BY 4.0 |
EC-Earth3-LR | EC-Earth-Consortium | 2019 | Published | EC-Earth3-LR | EC-Earth3-LR | CC BY 4.0 | @ec-earth.org <- cmip6-data | 2019-01-03: initially published under CC BY-SA 4.0; 2022-06-02: relaxed to CC BY 4.0 |
EC-Earth3-Veg | EC-Earth-Consortium | 2019 | Published | EC-Earth3-Veg | EC-Earth3-Veg | CC BY 4.0 | @ec-earth.org <- cmip6-data | 2019-04-10: initially published under CC BY-SA 4.0; 2022-06-02: relaxed to CC BY 4.0 |
EC-Earth3-Veg-LR | EC-Earth-Consortium | 2019 | Published | EC-Earth3-Veg-LR | EC-Earth3-Veg-LR | CC BY 4.0 | @ec-earth.org <- cmip6-data | 2020-02-13: initially published under CC BY-SA 4.0; 2022-06-02: relaxed to CC BY 4.0 |
EC-Earth3P | EC-Earth-Consortium | 2017 | Published | EC-Earth3P | EC-Earth 3.2 in PRIMAVERA | CC BY 4.0 | @ec-earth.org <- cmip6-data | 2017-09-11: initially published under CC BY-SA 4.0; 2022-06-02: relaxed to CC BY 4.0 |
EC-Earth3P-HR | EC-Earth-Consortium | 2017 | Published | EC-Earth3P-HR | EC-Earth3P-HR in PRIMAVERA | CC BY 4.0 | @ec-earth.org <- cmip6-data | 2017-08-11: initially published under CC BY-SA 4.0; 2022-06-02: relaxed to CC BY 4.0 |
EC-Earth3P-VHR | EC-Earth-Consortium | 2017 | Published | EC-Earth3P-VHR | EC-Earth3P-VHR in PRIMAVERA | CC BY 4.0 | @bsc.es <- pierre-antoine.bretonniere | 2020-10-07: initially published under CC BY-SA 4.0; 2022-06-02: relaxed to CC BY 4.0 |
ECMWF-IFS-HR | ECMWF | 2017 | Published | ECMWF-IFS-HR | ECMWF-IFS-HR (25 km atmosphere and 25 km ocean) | CC BY 4.0 | @ecmwf.int <- christopher.roberts | 2017-09-15: initially published under CC BY-NC-SA 4.0; 2022-07-26: relaxed to CC BY 4.0 |
ECMWF-IFS-LR | ECMWF | 2017 | Published | ECMWF-IFS-LR | ECMWF-IFS-LR (50 km atmosphere and 100 km ocean) | CC BY 4.0 | @ecmwf.int <- christopher.roberts | 2017-09-15: initially published under CC BY-NC-SA 4.0; 2022-07-26: relaxed to CC BY 4.0 |
ECMWF-IFS-MR | ECMWF | 2017 | Published | ECMWF-IFS-MR | ECMWF-IFS-MR (50 km atmosphere and 25 km ocean) | CC BY 4.0 | @ecmwf.int <- christopher.roberts | 2018-11-15: initially published under CC BY-NC-SA 4.0; 2022-07-26: relaxed to CC BY 4.0 |
FGOALS-f3-H | CAS | 2017 | Published | FGOALS-f3-H | FGOALS-f3-H | CC BY 4.0 | @mail.iap.ac.cn <- linpf | 2019-08-16: initially published under CC BY-SA 4.0; 2022-10-04: relaxed to CC BY 4.0 |
FGOALS-f3-L | CAS | 2017 | Published | FGOALS-f3-L | FGOALS-f3-L | CC BY 4.0 | @mail.iap.ac.cn <- linpf | 2018-11-08: initially published under CC BY-SA 4.0; 2022-10-04: relaxed to CC BY 4.0 |
FGOALS-g3 | CAS | 2017 | Published | FGOALS-g3 | FGOALS-g3 | CC BY 4.0 | @mail.iap.ac.cn <- linpf | 2019-08-18: initially published under CC BY-SA 4.0; 2022-10-04: relaxed to CC BY 4.0 |
FIO-ESM-2-0 | FIO-QLNM | 2018 | Published | FIO-ESM 2.0 | FIO-ESM 2.0 | CC BY 4.0 | @fio.org.cn <- songroy | 2019-09-10: initially published under CC BY-SA 4.0; 2022-09-27: relaxed to CC BY 4.0 |
GFDL-AM4 | NOAA-GFDL | 2018 | Published | GFDL-AM4 | GFDL-AM4 | CC BY 4.0 | @noaa.gov <- gfdl.climate.model.info | 2018-03-01: initially published under CC BY-SA 4.0; 2022-06-08: relaxed to CC BY 4.0 |
GFDL-CM4 | NOAA-GFDL | 2018 | Published | GFDL-CM4 | GFDL-CM4 | CC BY 4.0 | @noaa.gov <- gfdl.climate.model.info | 2018-03-01: initially published under CC BY-SA 4.0; 2022-06-08: relaxed to CC BY 4.0 |
GFDL-CM4C192 | NOAA-GFDL | 2018 | Published | GFDL-CM4C192 | GFDL-CM4C192 | CC BY 4.0 | @noaa.gov <- gfdl.climate.model.info | 2018-07-01: initially published under CC BY-SA 4.0; 2022-06-08: relaxed to CC BY 4.0 |
GFDL-ESM2M | NOAA-GFDL | 2012 | Published | GFDL-ESM2M | GFDL-ESM2M | CC BY 4.0 | @noaa.gov <- gfdl.climate.model.info | 2018-07-01: initially published under CC BY-SA 4.0; 2022-06-08: relaxed to CC BY 4.0 |
GFDL-ESM4 | NOAA-GFDL | 2018 | Published | GFDL-ESM4 | GFDL-ESM4 | CC BY 4.0 | @noaa.gov <- gfdl.climate.model.info | 2018-07-01: initially published under CC BY-SA 4.0; 2022-06-08: relaxed to CC BY 4.0 |
GFDL-GRTCODE | NOAA-GFDL | 2019 | Published | GFDL-GRTCODE | GFDL GPU radiative transfer code with two stream solver (March 2019) | CC BY 4.0 | @noaa.gov <- gfdl.climate.model.info | 2018-07-01: initially published under CC BY-NC-SA 4.0; 2022-06-08: relaxed to CC BY 4.0 |
GFDL-OM4p5B | NOAA-GFDL | 2018 | Published | GFDL-OM4p5B | GFDL-OM4p5B | CC BY 4.0 | @noaa.gov <- gfdl.climate.model.info | 2018-07-01: initially published under CC BY-SA 4.0; 2022-06-08: relaxed to CC BY 4.0 |
GFDL-RFM-DISORT | NOAA-GFDL | 2019 | Published | GFDL-RFM-DISORT | GFDL Reference Forward Model Line-by-Line with DISORT solver (March 2019) | CC BY 4.0 | @noaa.gov <- gfdl.climate.model.info | 2018-07-01: initially published under CC BY-NC-SA 4.0; 2022-06-08: relaxed to CC BY 4.0 |
GISS-E2-1-G | NASA-GISS | 2019 | Published | GISS-E2.1G | GISS-E2.1G | CC0 1.0 | @lists.nasa.gov <- cmip-giss-l | 2018-08-21: initially published under CC BY-SA 4.0; 2021-12-01: relaxed to CC0 1.0 | https://data.giss.nasa.gov/modelE/cmip6/#datalicense
GISS-E2-1-G-CC | NASA-GISS | 2019 | Published | GISS-E2-1-G-CC | GISS-E2-1-G-CC | CC0 1.0 | @lists.nasa.gov <- cmip-giss-l | 2019-03-25: initially published under CC BY-SA 4.0; 2021-12-01: relaxed to CC0 1.0 | https://data.giss.nasa.gov/modelE/cmip6/#datalicense
GISS-E2-1-H | NASA-GISS | 2019 | Published | GISS-E2.1H | GISS-E2.1H | CC0 1.0 | @lists.nasa.gov <- cmip-giss-l | 2018-08-24: initially published under CC BY-SA 4.0; 2021-12-01: relaxed to CC0 1.0 | https://data.giss.nasa.gov/modelE/cmip6/#datalicense
GISS-E2-2-G | NASA-GISS | 2019 | Published | GISS-E2-2-G | GISS-E2-2-G | CC0 1.0 | @lists.nasa.gov <- cmip-giss-l | 2019-11-20: initially published under CC BY-SA 4.0; 2021-12-01: relaxed to CC0 1.0 | https://data.giss.nasa.gov/modelE/cmip6/#datalicense
GISS-E2-2-H | NASA-GISS | 2021 | Published | GISS-E2.2H | GISS-E2.2H | CC0 1.0 | @lists.nasa.gov <- cmip-giss-l | 2019-11-20: initially published under CC BY-SA 4.0; 2021-12-01: relaxed to CC0 1.0 | https://data.giss.nasa.gov/modelE/cmip6/#datalicense
GISS-E3-G | NASA-GISS | 2020 | Published | GISS-E3-G | GISS-E3-G | CC0 1.0 | @lists.nasa.gov <- cmip-giss-l | 2019-12-30: initially published under CC BY-NC-SA 4.0; 2021-12-01: relaxed to CC0 1.0 | https://data.giss.nasa.gov/modelE/cmip6/#datalicense
HadGEM3-GC31-HH | MOHC NERC | 2016 | Published | HadGEM3-GC31-HH | HadGEM3-GC3.1-N512ORCA12 | CC BY 4.0 | @metoffice.gov.uk <- cmip6.hadgem3 | 2018-09-27: initially published under CC BY-SA 4.0; 2021-11-15: relaxed to CC BY 4.0 | https://ukesm.ac.uk/licensing-of-met-office-nerc-and-niwa-cmip6-data/
HadGEM3-GC31-HM | MOHC NERC | 2016 | Published | HadGEM3-GC31-HM | HadGEM3-GC3.1-N512ORCA025 | CC BY 4.0 | @metoffice.gov.uk <- cmip6.hadgem3 | 2017-08-31: initially published under CC BY-SA 4.0; 2021-11-15: relaxed to CC BY 4.0 | https://ukesm.ac.uk/licensing-of-met-office-nerc-and-niwa-cmip6-data/
HadGEM3-GC31-LL | MOHC NERC | 2016 | Published | HadGEM3-GC31-LL | HadGEM3-GC3.1-N96ORCA1 | CC BY 4.0 | @metoffice.gov.uk <- cmip6.hadgem3 | 2017-09-21: initially published under CC BY-SA 4.0; 2021-11-15: relaxed to CC BY 4.0 | https://ukesm.ac.uk/licensing-of-met-office-nerc-and-niwa-cmip6-data/
HadGEM3-GC31-LM | MOHC | 2016 | Published | HadGEM3-GC31-LM | HadGEM3-GC3.1-N96ORCA025 | CC BY 4.0 | @metoffice.gov.uk <- cmip6.hadgem3 | 2017-09-06: initially published under CC BY-SA 4.0; 2021-11-15: relaxed to CC BY 4.0 | https://ukesm.ac.uk/licensing-of-met-office-nerc-and-niwa-cmip6-data/
HadGEM3-GC31-MH | MOHC | 2016 | Published | HadGEM3-GC31-MH | HadGEM3-GC3.1-N216ORCA12 | CC BY 4.0 | @metoffice.gov.uk <- cmip6.hadgem3 | 2017-12-27: initially published under CC BY-SA 4.0; 2021-11-15: relaxed to CC BY 4.0 | https://ukesm.ac.uk/licensing-of-met-office-nerc-and-niwa-cmip6-data/
HadGEM3-GC31-MM | MOHC | 2016 | Published | HadGEM3-GC31-MM | HadGEM3-GC3.1-N216ORCA025 | CC BY 4.0 | @metoffice.gov.uk <- cmip6.hadgem3 | 2017-08-18: initially published under CC BY-SA 4.0; 2021-11-15: relaxed to CC BY 4.0 | https://ukesm.ac.uk/licensing-of-met-office-nerc-and-niwa-cmip6-data/
HiRAM-SIT-HR | AS-RCEC | 2018 | Published | HiRAM-SIT-HR | HiRAM Coupling 1-D SIT (25 km atmosphere and 25 km ocean) | CC BY 4.0 | @gate.sinica.edu.tw <- cytu | 2020-12-23: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
HiRAM-SIT-LR | AS-RCEC | 2018 | Published | HiRAM-SIT-LR | HiRAM Coupling 1-D SIT (50 km atmosphere and 25 km ocean) | CC BY 4.0 | @gate.sinica.edu.tw <- cytu | 2020-12-29: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
ICON-ESM-LR | MPI-M | 2017 | Published | ICON-ESM-LR | ICON-ESM-LR | CC BY 4.0 | @dkrz.de <- cmip6-mpi-esm | 2021-02-15: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
IITM-ESM | CCCR-IITM | 2015 | Published | IITM-ESM | IITM-ESM | CC BY 4.0 | @tropmet.res.in <- iitm-esm | 2019-07-19: initially published under CC BY-SA 4.0; 2022-09-27: relaxed to CC BY 4.0 |
INM-CM4-8 | INM | 2016 | Published | INM-CM4-8 | INM-CM4-8 | CC BY 4.0 | @gmail.com <- volodinev | 2019-05-28: initially published under CC BY-SA 4.0; 2022-09-27: relaxed to CC BY 4.0 |
INM-CM5-0 | INM | 2016 | Published | INM-CM5-0 | INM-CM5-0 | CC BY 4.0 | @gmail.com <- volodinev | 2019-06-10: initially published under CC BY-SA 4.0; 2022-09-27: relaxed to CC BY 4.0 |
INM-CM5-H | INM | 2016 | Published | INM-CM5-H | INM-CM5-H | CC BY 4.0 | @gmail.com <- volodinev | 2019-08-12: initially published under CC BY-SA 4.0; 2022-09-27: relaxed to CC BY 4.0 |
IPSL-CM5A2-INCA | IPSL | 2019 | Published | IPSL-CM5A2-INCA | IPSL-CM5A2-INCA | CC BY 4.0 | @listes.ipsl.fr <- ipsl-cmip6 | 2020-07-29: initially published under CC BY-NC-SA 4.0; 2022-06-03: relaxed to CC BY 4.0 |
IPSL-CM6A-ATM-HR | IPSL | 2018 | Published | IPSL-CM6A-ATM-HR | IPSL-CM6A-ATM-HR | CC BY 4.0 | @listes.ipsl.fr <- ipsl-cmip6 | 2019-01-22: initially published under CC BY-NC-SA 4.0; 2022-06-03: relaxed to CC BY 4.0 |
IPSL-CM6A-ATM-ICO-HR | IPSL | 2021 | Published | IPSL-CM6A-ATM-ICO-HR | IPSL-CM6A-ATM-ICO-HR | CC BY 4.0 | @listes.ipsl.fr <- ipsl-cmip6 | 2022-07-21: initially published under CC BY 4.0 |
IPSL-CM6A-ATM-ICO-LR | IPSL | 2021 | Published | IPSL-CM6A-ATM-ICO-LR | IPSL-CM6A-ATM-ICO-LR | CC BY 4.0 | @listes.ipsl.fr <- ipsl-cmip6 | 2022-07-21: initially published under CC BY 4.0 |
IPSL-CM6A-ATM-ICO-MR | IPSL | 2021 | Published | IPSL-CM6A-ATM-ICO-MR | IPSL-CM6A-ATM-ICO-MR | CC BY 4.0 | @listes.ipsl.fr <- ipsl-cmip6 | 2022-07-20: initially published under CC BY 4.0 |
IPSL-CM6A-ATM-ICO-VHR | IPSL | 2021 | Published | IPSL-CM6A-ATM-ICO-VHR | IPSL-CM6A-ATM-ICO-VHR | CC BY 4.0 | @listes.ipsl.fr <- ipsl-cmip6 | 2022-07-21: initially published under CC BY 4.0 |
IPSL-CM6A-ATM-LR-REPROBUS | IPSL | 2021 | Published | IPSL-CM6A-ATM-LR-REPROBUS | IPSL-CM6A-ATM-LR-REPROBUS | CC BY 4.0 | @listes.ipsl.fr <- ipsl-cmip6 | 2024-06-18: initially published under CC BY 4.0 |
IPSL-CM6A-LR | IPSL | 2017 | Published | IPSL-CM6A-LR | IPSL-CM6A-LR | CC BY 4.0 | @listes.ipsl.fr <- ipsl-cmip6 | 2018-03-14: initially published under CC BY-NC-SA 4.0; 2022-06-03: relaxed to CC BY 4.0 |
IPSL-CM6A-LR-INCA | IPSL | 2019 | Published | IPSL-CM6A-LR-INCA | IPSL-CM6A-LR-INCA | CC BY 4.0 | @listes.ipsl.fr <- ipsl-cmip6 | 2020-07-17: initially published under CC BY-NC-SA 4.0; 2022-06-03: relaxed to CC BY 4.0 |
IPSL-CM6A-MR1 | IPSL | 2021 | Published | IPSL-CM6A-MR1 | IPSL-CM6A-MR1 | CC BY 4.0 | @listes.ipsl.fr <- ipsl-cmip6 | 2024-03-26: initially published under CC BY 4.0 |
KACE-1-0-G | NIMS-KMA | 2018 | Published | KACE1.0-G | KACE1.0-GLOMAP | CC BY 4.0 | @korea.kr <- sunghm122 | 2019-08-13: initially published under CC BY-SA 4.0; 2022-09-28 relaxed to CC BY 4.0 |
KIOST-ESM | KIOST | 2018 | Published | KIOST-ESM | KIOST Earth System Model v2 | CC BY 4.0 | @pknu.ac.kr <- yhokim | 2019-11-04: initially published under CC BY-SA 4.0; 2022-09-28 relaxed to CC BY 4.0 |
LBLRTM-12-8 | AER | 2017 | Published | LBLRTM 12.8 | Line-By-Line Radiative Transfer Model v12.8, aer_v_3.6, MT_CKD_3.2 | CC BY 4.0 | @aer.com <- aer_lblrtm | 2019-05-14: initially published under CC BY-NC-SA 4.0; 2022-10-07: relaxed to CC BY 4.0 |
MCM-UA-1-0 | UA | 1991 | Published | MCM-UA-1-0 | Manabe Climate Model v1.0 - University of Arizona | CC BY 4.0 | @email.arizona.edu <- GEOS-CMIP | 2019-07-31: initially published under CC BY-SA 4.0; 2022-06-02: relaxed to CC BY 4.0 |
MIROC-ES2H | MIROC | 2018 | Published | MIROC-ES2H | MIROC-ES2H | CC BY 4.0 | @jamstec.go.jp <- miroc-cmip6 | 2021-01-25: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
MIROC-ES2H-NB | MIROC | 2019 | Published | MIROC-ES2H-NB | MIROC-ES2H with No BiogenicCycle | CC BY 4.0 | @jamstec.go.jp <- miroc-cmip6 | 2020-04-28: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
MIROC-ES2L | MIROC | 2018 | Published | MIROC-ES2L | MIROC-ES2L | CC BY 4.0 | @jamstec.go.jp <- miroc-cmip6 | 2019-08-23: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
MIROC6 | MIROC | 2017 | Published | MIROC6 | MIROC6 | CC BY 4.0 | @jamstec.go.jp <- miroc-cmip6 | 2018-12-12: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
MPI-ESM-1-2-HAM | HAMMOZ-Consortium | 2017 | Published | MPI-ESM1.2-HAM | MPI-ESM1.2-HAM | CC BY 4.0 | @sympa.ethz.ch <- aerchemmip_echam-ham | 2019-06-27: initially published under CC BY-SA 4.0; 2022-07-27: relaxed to CC BY 4.0 |
MPI-ESM1-2-HR | MPI-M DWD DKRZ | 2017 | Published | MPI-ESM1.2-HR | MPI-ESM1.2-HR | CC BY 4.0 | @dkrz.de <- cmip6-mpi-esm | 2017-10-03: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
MPI-ESM1-2-LR | MPI-M AWI DKRZ DWD | 2017 | Published | MPI-ESM1.2-LR | MPI-ESM1.2-LR | CC BY 4.0 | @dkrz.de <- cmip6-mpi-esm | 2019-07-10: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
MPI-ESM1-2-XR | MPI-M | 2017 | Published | MPI-ESM1.2-XR | MPI-ESM1.2-XR | CC BY 4.0 | @dkrz.de <- cmip6-mpi-esm | 2017-10-03: initially published under CC BY-SA 4.0; 2022-06-16: relaxed to CC BY 4.0 |
MRI-AGCM3-2-H | MRI | 2017 | Published | MRI-AGCM3-2-H | MRI-AGCM3-2-H | CC BY 4.0 | @mri-jma.go.jp <- rmizuta | 2019-07-11: initially published under CC BY-SA 4.0; 2022-08-07: relaxed to CC BY 4.0 |
MRI-AGCM3-2-S | MRI | 2017 | Published | MRI-AGCM3-2-S | MRI-AGCM3-2-S | CC BY 4.0 | @mri-jma.go.jp <- rmizuta | 2019-07-11: initially published under CC BY-SA 4.0; 2022-08-07: relaxed to CC BY 4.0 |
MRI-ESM2-0 | MRI | 2017 | Published | MRI-ESM2.0 | MRI-ESM2.0 | CC BY 4.0 | @mri-jma.go.jp <- mdeushi | 2019-02-22: initially published under CC BY-SA 4.0; 2022-08-07: relaxed to CC BY 4.0 |
NESM3 | NUIST | 2016 | Published | NESM v3 | NUIST ESM v3 | CC BY 4.0 | @nuist.edu.cn <- esmc | 2019-06-25: initially published under CC BY-SA 4.0; 2022-10-05: relaxed to CC BY 4.0 |
NICAM16-7S | MIROC | 2017 | Published | NICAM16-7S | NICAM.16 gl07-L38 with NSW6 | CC BY 4.0 | @jamstec.go.jp <- miroc-cmip6 | 2019-03-18: initially published under CC BY-SA 4.0; 2022-06-14: relaxed to CC BY 4.0 |
NICAM16-8S | MIROC | 2017 | Published | NICAM16-8S | NICAM.16 gl08-L38 with NSW6 | CC BY 4.0 | @jamstec.go.jp <- miroc-cmip6 | 2019-08-30: initially published under CC BY-SA 4.0; 2022-06-14: relaxed to CC BY 4.0 |
NICAM16-9S | MIROC | 2017 | Published | NICAM16-9S | NICAM.16 gl09-L38 with NSW6 | CC BY 4.0 | @jamstec.go.jp <- miroc-cmip6 | 2019-08-30: initially published under CC BY-SA 4.0; 2022-06-14: relaxed to CC BY 4.0 |
NorCPM1 | NCC | 2019 | Published | NorCPM1 | Norwegian Climate Prediction Model version 1 | CC BY 4.0 | @uib.no <- norcpm | 2019-09-14: initially published under CC BY-SA 4.0; 2022-06-03: relaxed to CC BY 4.0 |
NorESM1-F | NCC | 2018 | Published | NorESM1-F | NorESM1-F (a fast version of NorESM that is designed for paleo and multi-ensemble simulations) | CC BY 4.0 | @met.no <- noresm-ncc | 2019-09-20: initially published under CC BY-SA 4.0; 2022-06-03: relaxed to CC BY 4.0 |
NorESM2-LM | NCC | 2017 | Published | NorESM2-LM | NorESM2-LM (low atmosphere-medium ocean resolution, GHG concentration driven) | CC BY 4.0 | @met.no <- noresm-ncc | 2019-08-15: initially published under CC BY-SA 4.0; 2022-06-03: relaxed to CC BY 4.0 |
NorESM2-MM | NCC | 2017 | Published | NorESM2-MM | NorESM2-MM (medium atmosphere-medium ocean resolution, GHG concentration driven) | CC BY 4.0 | @met.no <- noresm-ncc | 2019-11-08: initially published under CC BY-SA 4.0; 2022-06-03: relaxed to CC BY 4.0 |
PCMDI-test-1-0 | PCMDI | 1989 | Registered | PCMDI-test 1.0 | PCMDI-test 1.0 (This entry is free text for users to contribute verbose information) |  |  |  |
RRTMG-LW-4-91 | AER | 2017 | Published | RRTMG-LW 4.91 | RRTM for GCMs v4.91, longwave | CC BY 4.0 | @aer.com <- aer_rrtmg | 2020-01-10: initially published under CC BY-NC-SA 4.0; 2022-10-07: relaxed to CC BY 4.0 |
RRTMG-SW-4-02 | AER | 2017 | Published | RRTMG-SW 4.02 | RRTM for GCMs v4.02, shortwave | CC BY 4.0 | @aer.com <- aer_rrtmg | 2020-01-10: initially published under CC BY-NC-SA 4.0; 2022-10-07: relaxed to CC BY 4.0 |
RTE-RRTMGP-181204 | RTE-RRTMGP-Consortium | 2019 | Published | RTE+RRTMGP (2018-12-04 full-resolution) | Radiative Transfer for Energetics using RRTM for GCM applications - Parallel (2018-12-04 full-resolution) | CC BY 4.0 | @aer.com <- aer_rrtmgp | 2019-10-07: initially published under CC BY-NC-SA 4.0; 2022-10-07: relaxed to CC BY 4.0 |
SAM0-UNICON | SNU | 2017 | Published | SAM0-UNICON | SAM0-UNICON (SNU Atmosphere Model version 0 with Unified Convection Scheme) | CC BY 4.0 | @snu.ac.kr <- sungsup | 2019-03-23: initially published under CC BY-SA 4.0; 2022-10-12: relaxed to CC BY 4.0 |
TaiESM1 | AS-RCEC | 2018 | Published | TaiESM 1.0 | Taiwan Earth System Model 1.0 | CC BY 4.0 | @gate.sinica.edu.tw <- leelupin | 2019-12-25: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
TaiESM1-TIMCOM | NTU | 2020 | Published | TaiESM1-TIMCOM | Taiwan Earth System Model 1.0 using TIMCOM ocean model | CC BY 4.0 | @ntu.edu.tw <- tsengyh | 2020-09-29: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
TaiESM1-TIMCOM2 | NTU | 2021 | Published | TaiESM1-TIMCOM2 | Taiwan Earth System Model 1.0 using TIMCOM ocean model 2.0 | CC BY 4.0 | @ntu.edu.tw <- tsengyh | 2021-12-13: initially published under CC BY-SA 4.0; 2022-06-10: relaxed to CC BY 4.0 |
UKESM1-0-LL | MOHC NERC NIMS-KMA NIWA | 2018 | Published | UKESM1.0-LL | UKESM1.0-N96ORCA1 | CC BY 4.0 | @metoffice.gov.uk <- cmip6.ukesm1 | 2019-04-04: initially published under CC BY-SA 4.0; 2021-11-15: relaxed to CC BY 4.0 | https://ukesm.ac.uk/licensing-of-met-office-nerc-and-niwa-cmip6-data/
UKESM1-1-LL | MOHC NERC NIMS-KMA NIWA | 2021 | Published | UKESM1.1-LL | UKESM1.1-N96ORCA1 | CC BY 4.0 | @metoffice.gov.uk <- cmip6.ukesm1 | 2022-05-04: initially published under CC BY-SA 4.0; 2022-05-04: relaxed to CC BY 4.0 | https://ukesm.ac.uk/licensing-of-met-office-nerc-and-niwa-cmip6-data/
UKESM1-ice-LL | MOHC NERC | 2019 | Published | UKESM1.ice-LL | UKESM1.ice-N96ORCA1 | CC BY 4.0 | @metoffice.gov.uk <- cmip6.ukesm1 | 2022-02-11: initially published under CC BY-SA 4.0; 2022-02-11: relaxed to CC BY 4.0 | https://ukesm.ac.uk/licensing-of-met-office-nerc-and-niwa-cmip6-data/